%global alt_name GPaste

Name:           gpaste
Version:        3.6
Release:        1%{?dist}
Summary:        Clipboard management system

Group:          User Interface/Desktops
License:        GPLv3+
URL:            https://github.com/Keruspe/GPaste
Source0:        http://www.imagination-land.org/files/%{name}/%{name}-%{version}.tar.xz

BuildRequires:  chrpath
BuildRequires:  desktop-file-utils
BuildRequires:  intltool
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gnome-keybindings)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  vala-tools
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}
Requires:       control-center-filesystem

%description
gpasted is a clipboard management daemon with DBus interface. gpaste is its CLI
client and gpaste-settings is a tool to edit gpasted settings.


%package libs
Summary:        Library to manage the clipboard history
Group:          System Environment/Libraries

%description libs
libgpaste is a library to manage the clipboard history (used by gpasted).


%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for developing
applications that use %{name}.


%package -n gnome-shell-extension-%{name}
Summary:        GNOME Shell extension for GPaste
Group:          User Interface/Desktops
Requires:       gnome-shell >= 3.9.90
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description -n gnome-shell-extension-%{name}
%{summary}.


%package applet
Summary:        Tray icon to manage GPaste
Group:          User Interface/Desktops
Requires:       %{name} = %{version}-%{release}

%description applet
%{summary}.


%prep
%setup -q


%build
[ -f configure ] || NOCONFIGURE=1 ./autogen.sh
%configure \
  --disable-schemas-compile \
  --disable-silent-rules \
  --enable-applet \
  --enable-systemd \
  --enable-vala
make %{?_smp_mflags}


%install
make install DESTDIR=$RPM_BUILD_ROOT

rm $RPM_BUILD_ROOT%{_libdir}/*.la

# Install bash/zsh completion support
install -d $RPM_BUILD_ROOT%{_datadir}/bash-completion/completions/
install -pm 0644 data/completions/%{name} -t $RPM_BUILD_ROOT%{_datadir}/bash-completion/completions/
install -d $RPM_BUILD_ROOT%{_datadir}/zsh/site-functions/
install -pm 0644 data/completions/_%{name} -t $RPM_BUILD_ROOT%{_datadir}/zsh/site-functions/

# Move gpaste-applet desktop file to /etc/xdg/autostart
install -d $RPM_BUILD_ROOT%{_sysconfdir}/xdg/autostart/
mv $RPM_BUILD_ROOT%{_datadir}/applications/%{name}-applet.desktop $RPM_BUILD_ROOT%{_sysconfdir}/xdg/autostart/

%find_lang %{alt_name}

# Removing Rpath
 chrpath --delete $RPM_BUILD_ROOT%{_bindir}/* $RPM_BUILD_ROOT%{_libdir}/*.so.* $RPM_BUILD_ROOT%{_libexecdir}/%{name}/*


%check
desktop-file-validate $RPM_BUILD_ROOT%{_sysconfdir}/xdg/autostart/gpaste-applet.desktop
desktop-file-validate $RPM_BUILD_ROOT%{_datadir}/applications/%{name}-settings.desktop


%post libs -p /sbin/ldconfig


%postun libs -p /sbin/ldconfig


%postun
if [ $1 -eq 0 ]; then
  /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &>/dev/null || :
fi


%posttrans
/usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &>/dev/null || :


%files -f %{alt_name}.lang
%doc AUTHORS COPYING NEWS README.md THANKS TODO
%{_bindir}/%{name}
%{_libexecdir}/%{name}/
%{_datadir}/applications/%{name}-settings.desktop
%{_datadir}/dbus-1/services/*.service
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/gnome-control-center/keybindings/*.xml
%{_datadir}/zsh/
%{_mandir}/man1/%{name}.1.*
%{_datadir}/bash-completion/
%{_prefix}/lib/systemd/user/gpasted.service

%files libs
%{_libdir}/girepository-1.0/%{alt_name}-1.0.typelib
%{_libdir}/*.so.*


%files devel
%{_datadir}/gir-1.0/*.gir
%{_datadir}/vala/vapi/*
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc


%files applet
%{_libexecdir}/%{name}/%{name}-applet
%{_mandir}/man1/%{name}-applet.1.*
%{_sysconfdir}/xdg/autostart/%{name}-applet.desktop


%files -n gnome-shell-extension-%{name}
%{_datadir}/gnome-shell/extensions/GPaste@gnome-shell-extensions.gnome.org/


%changelog
* Thu Oct 17 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.6-1
- Update to 3.6

* Wed Sep 25 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.5-1
- Update to 3.5

* Mon Sep 23 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.5-0.2.20130922gitf124a2f
- Update to a newer snapshot

* Wed Sep 18 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.5-0.1.20130918git6ab4033
- Update to a newer snapshot

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Jun 02 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.0.2-1
- Update to 3.0.2

* Fri May 10 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.0.1-2
- Fix bash completion

* Fri May 10 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.0.1-1
- Update to 3.0.1

* Sun Apr 07 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.99.2-3.20130331gitc93a4ac
- Add missing BuildRequires on pkgconfig(gnome-keybindings)

* Sun Apr 07 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.99.2-2.20130331gitc93a4ac
- Update to a newer snapshot
- Move bash completion script to /usr/share/bash-completion/completion/

* Mon Jan 28 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.99.2-1
- Update to 2.99.2
- Drop patch gpaste-2.99.1-fix_gpaste-settings

* Thu Jan 17 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.99.1-1
- Update to 2.99.1

* Sun Dec 30 2012 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.9.1-1
- Update to 2.9.1
- Drop patch gpaste-2.9-gir.patch, fixed upstream

* Sun Sep 30 2012 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.9-1
- Update to 2.9
- Enable GNOME fallback applet

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.8.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat May 19 2012 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.8.1-1
- Update to 2.8.1

* Thu May 03 2012 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.8-1
- Update to 2.8

* Sun Apr 08 2012 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.5-2
- Fix Group and Requires tags in subpackages

* Fri Mar 30 2012 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.5-1
- Update to 2.5

* Sat Jan 07 2012 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.2.1-1
- Update to 2.2.1

* Fri Dec 09 2011 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.1-1
- Update to 2.1

* Tue Nov 29 2011 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.0-1
- Update to 2.0

* Sun Sep 25 2011 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.6-1
- Update to 1.6
- Remove no longer needed gpaste-1.5-DOS.patch patch

* Wed Sep 14 2011 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.5-1
- Update to 1.5
- Remove gpaste-1.3-remove_applet_refs.patch patch (there is no more reference
  to the GNOME 2 applet in documentation and completion files)
- Add gpaste-1.5-DSO.patch to fix DSO linking

* Sat Sep 03 2011 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.3-1
- Update to 1.3

* Sun Jul 10 2011 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.2-1
- Update to 1.2

* Sat Jun 25 2011 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.99-1.17dd47git
- Initial RPM release
